@@ -3,56 +3,51 @@
 import sys
 
 import time
-import numarray as NA
 from tables import *
 import random
 import math
 import warnings
-import numarray
-from numarray import strings
-from numarray import random_array
+import numpy
 
 # Initialize the random generator always with the same integer
 # in order to have reproductible results
 random.seed(19)
-random_array.seed(19, 20)
+numpy.random.seed(19)
 
 randomvalues = 0
 worst=0
 
 Small = {
-    #"_v_indexprops" : IndexProps(auto=1),
-    # var1 column will be indexed if not heavy test
-    "var1" : StringCol(length=4, dflt="Hi!", indexed=1, pos=2),
-    "var2" : IntCol(0, indexed=1, pos=1),
-    "var3" : FloatCol(0, indexed=1, pos=0),
-    #"var4" : BoolCol(0, indexed=1),
+    "var1" : StringCol(itemsize=4, dflt="Hi!", pos=2),
+    "var2" : Int32Col(pos=1),
+    "var3" : Float64Col(pos=0),
+    #"var4" : BoolCol(),
     }
 
 def createNewBenchFile(bfile, verbose):
 
     class Create(IsDescription):
-        nrows   = IntCol(pos=0)
-        irows   = IntCol(pos=1)
-        tfill   = FloatCol(pos=2)
-        tidx    = FloatCol(pos=3)
-        tcfill  = FloatCol(pos=4)
-        tcidx   = FloatCol(pos=5)
-        rowsecf = FloatCol(pos=6)
-        rowseci = FloatCol(pos=7)
-        fsize   = FloatCol(pos=8)
-        isize   = FloatCol(pos=9)
+        nrows   = Int32Col(pos=0)
+        irows   = Int32Col(pos=1)
+        tfill   = Float64Col(pos=2)
+        tidx    = Float64Col(pos=3)
+        tcfill  = Float64Col(pos=4)
+        tcidx   = Float64Col(pos=5)
+        rowsecf = Float64Col(pos=6)
+        rowseci = Float64Col(pos=7)
+        fsize   = Float64Col(pos=8)
+        isize   = Float64Col(pos=9)
         psyco   = BoolCol(pos=10)
 
     class Search(IsDescription):
-        nrows   = IntCol(pos=0)
-        rowsel  = IntCol(pos=1)
-        time1   = FloatCol(pos=2)
-        time2   = FloatCol(pos=3)
-        tcpu1   = FloatCol(pos=4)
-        tcpu2   = FloatCol(pos=5)
-        rowsec1 = FloatCol(pos=6)
-        rowsec2 = FloatCol(pos=7)
+        nrows   = Int32Col(pos=0)
+        rowsel  = Int32Col(pos=1)
+        time1   = Float64Col(pos=2)
+        time2   = Float64Col(pos=3)
+        tcpu1   = Float64Col(pos=4)
+        tcpu2   = Float64Col(pos=5)
+        rowsec1 = Float64Col(pos=6)
+        rowsec2 = Float64Col(pos=7)
         psyco   = BoolCol(pos=8)
 
     if verbose:
@@ -80,28 +75,20 @@ def createNewBenchFile(bfile, verbose):
                     bf.createTable(groupM, atom, Search, atom+" bench")
     bf.close()
 
-def createFile(filename, nrows, filters, index, heavy, auto, verbose):
+def createFile(filename, nrows, filters, index, heavy, noise, verbose):
 
     # Open a file in "w"rite mode
     fileh = openFile(filename, mode = "w", title="Searchsorted Benchmark",
                      filters=filters)
     rowswritten = 0
-    # set the properties of the index (the same of table)
-    if index:
-        Small["_v_indexprops"] = IndexProps(auto=auto, filters=filters)
-    else:
-        auto = 0
-        Small["_v_indexprops"] = IndexProps(auto=0, filters=filters)
-    if heavy:
-        # make the string entry not indexed
-        Small["var1"] = StringCol(length=4, dflt="Hi!", indexed=0)
 
     # Create the test table
     table = fileh.createTable(fileh.root, 'table', Small, "test table",
                               None, nrows)
+
     t1 = time.time()
     cpu1 = time.clock()
-    nrowsbuf = table._v_maxTuples
+    nrowsbuf = table.nrowsinbuf
     minimum = 0
     maximum = nrows
     for i in xrange(0, nrows, nrowsbuf):
@@ -110,19 +97,16 @@ def createFile(filename, nrows, filters, index, heavy, auto, verbose):
         else:
             j = i+nrowsbuf
         if randomvalues:
-            var3 = random_array.uniform(minimum, maximum, shape=[j-i])
+            var3 = numpy.random.uniform(minimum, maximum, size=j-i)
         else:
-            var3 = numarray.arange(i, j, type=numarray.Float64)
-            #var3 += random_array.uniform(-3, 3, shape=[j-i])
-        var2 = numarray.array(var3, type=numarray.Int32)
-        var1 = strings.array(None, shape=[j-i], itemsize=4)
+            var3 = numpy.arange(i, j, dtype=numpy.float64)
+            if noise > 0:
+                var3 += numpy.random.uniform(-noise, noise, size=j-i)
+        var2 = numpy.array(var3, dtype=numpy.int32)
+        var1 = numpy.empty(shape=[j-i], dtype="S4")
         if not heavy:
-            for n in xrange(j-i):
-                var1[n] = str("%.4s" % var2[n])
-#           var1[:] = str(var2)[:4]
-        else:
-            var1[:] = "Hi !"
-        table.append([var3*var3, var2, var1])
+            var1[:] = var2
+        table.append([var3, var2, var1])
     table.flush()
     rowswritten += nrows
     time1 = time.time()-t1
@@ -140,15 +124,14 @@ def createFile(filename, nrows, filters, index, heavy, auto, verbose):
         t1 = time.time()
         cpu1 = time.clock()
         # Index all entries
-        if not auto:
-            indexrows = table.flushRowsToIndex()
-        else:
-            indexrows = table.cols.var2.index.nelements
+        if not heavy:
+            indexrows = table.cols.var1.createIndex(filters=filters)
+        for colname in ['var2', 'var3']:
+            table.colinstances[colname].createIndex(filters=filters)
         time2 = time.time()-t1
-        if not auto:
-            print "Time for indexing:", round(time2,3), \
-                  "iKrows/s:", round(indexrows/1000./time2,3),
         tcpu2 = time.clock()-cpu1
+        print "Time for indexing:", round(time2,3), \
+              "iKrows/s:", round(indexrows/1000./time2,3),
     else:
         indexrows = 0
         time2 = 0.0000000001  # an ugly hack
@@ -164,13 +147,13 @@ def createFile(filename, nrows, filters, index, heavy, auto, verbose):
     fileh.close()
 
     size2 = os.stat(filename)[6] - size1
-    if not auto and index:
+    if index:
         print ", Index size:", round(size2/(1024.*1024.), 3), "MB"
     return (rowswritten, indexrows, rowsize, time1, time2,
             tcpu1, tcpu2, size1, size2)
 
-def benchCreate(file, nrows, filters, index, bfile, heavy, auto,
-                psyco, verbose):
+def benchCreate(file, nrows, filters, index, bfile, heavy,
+                psyco, noise, verbose):
 
     # Open the benchfile in append mode
     bf = openFile(bfile,"a")
@@ -181,7 +164,7 @@ def benchCreate(file, nrows, filters, index, bfile, heavy, auto,
         table = bf.getNode("/"+recsize+"/create_best")
 
     (rowsw, irows, rowsz, time1, time2, tcpu1, tcpu2, size1, size2) = \
-            createFile(file, nrows, filters, index, heavy, auto, verbose)
+          createFile(file, nrows, filters, index, heavy, noise, verbose)
     # Collect data
     table.row["nrows"] = rowsw
     table.row["irows"] = irows
@@ -208,15 +191,14 @@ def benchCreate(file, nrows, filters, index, bfile, heavy, auto,
     cpuidxrows = round(tcpu2, 3)
     tpercent = int(round(cpuidxrows/tidxrows, 2)*100)
     print "Rows indexed:", irows, " (IMRows):", irows / float(10**6)
-    if not auto:
-        print "Time indexing rows: %s s (real) %s s (cpu)  %s%%" % \
-              (round(tidxrows,3), cpuidxrows, tpercent)
+    print "Time indexing rows: %s s (real) %s s (cpu)  %s%%" % \
+          (round(tidxrows,3), cpuidxrows, tpercent)
     rowseci = irows / tidxrows
     table.row["rowseci"] = rowseci
     table.row.append()
     bf.close()
 
-def readFile(filename, atom, riter, indexmode, verbose):
+def readFile(filename, atom, riter, indexmode, dselect, verbose):
     # Open the HDF5 file in read-only mode
 
     fileh = openFile(filename, mode = "r")
@@ -232,84 +214,59 @@ def readFile(filename, atom, riter, indexmode, verbose):
             indexmode = "inkernel"
             where = table._whereInRange
     elif indexmode == "inkernel":
-        where = table._whereInRange
+        where = table.where
     if verbose:
-        print "Max rows in buf:", table._v_maxTuples
+        print "Max rows in buf:", table.nrowsinbuf
         print "Rows in", table._v_pathname, ":", table.nrows
-        print "Buffersize:", table.rowsize * table._v_maxTuples
-        print "MaxTuples:", table._v_maxTuples
+        print "Buffersize:", table.rowsize * table.nrowsinbuf
+        print "MaxTuples:", table.nrowsinbuf
         if indexmode == "indexed":
             print "Chunk size:", var2.index.sorted.chunksize
             print "Number of elements per slice:", var2.index.nelemslice
             print "Slice number in", table._v_pathname, ":", var2.index.nrows
 
+    #table.nrowsinbuf = 10
+    #print "nrowsinbuf-->", table.nrowsinbuf
     rowselected = 0
     time2 = 0.
     tcpu2 = 0.
     results = []
     print "Select mode:", indexmode, ". Selecting for type:", atom
-    # The interval for look values at. This is aproximately equivalent to
-    # the number of elements to select
-    chunksize = 1000  # Change here for selecting more or less entries
     # Initialize the random generator always with the same integer
-    # in order to have reproductible results
+    # in order to have reproductible results on each read iteration
     random.seed(19)
-    random_array.seed(19, 20)
+    numpy.random.seed(19)
     for i in xrange(riter):
-        rnd = random.randrange(table.nrows)
+        # The interval for look values at. This is aproximately equivalent to
+        # the number of elements to select
+        rnd = numpy.random.randint(table.nrows)
         cpu1 = time.clock()
         t1 = time.time()
         if atom == "string":
+            val = str(rnd)[-4:]
             if indexmode in ["indexed", "inkernel"]:
                 results = [p.nrow
-                           # for p in where("1000" <= var1 <= "1010")]
-                           #for p in where(var1 == "1111")]
-                           for p in where(var1 == str(rnd)[-4:])]
+                           for p in where('var1 == val')]
             else:
                 results = [p.nrow for p in table
-                           # if "1000" <= p["var1"] <= "1010"]
-                           #if p["var1"] == "1111"]
-                           if p["var1"] == str(rnd)[-4:]]
+                           if p["var1"] == val]
         elif atom == "int":
+            val = rnd+dselect
             if indexmode in ["indexed", "inkernel"]:
                 results = [p.nrow
-                           # for p in where(2+i<= var2 < 10+i)]
-                           # for p in where(2<= var2 < 10)]
-                           # for p in where(110*i <= var2 < 110*(i+1))]
-                           # for p in where(1000-30 < var2 < 1000+60)]
-                           # for p in where(3 <= var2 < 5)]
-                           #for p in where(rnd <= var2 < rnd+3)]
-                           for p in where(rnd <= var2 < rnd+chunksize)]
+                           for p in where('(rnd <= var3) & (var3 < val)')]
             else:
                 results = [p.nrow for p in table
-                           # if p["var2"] < 10+i]
-                           # if 2 <= p["var2"] < 10)]
-                           # if 110*i <= p["var2"] < 110*(i+1)]
-                           # if 1000-30 < p["var2"] < 1000+60]
-                           #if 3 <= p["var2"] < 5]
-                           #if rnd <= p["var2"] < rnd+3]
-                           if rnd <= p["var2"] < rnd+chunksize]
+                           if rnd <= p["var2"] < val]
         elif atom == "float":
+            val = rnd+dselect
             if indexmode in ["indexed", "inkernel"]:
                 t1=time.time()
                 results = [p.nrow
-                           # for p in where(var3 < 5.)]
-                           #for p in where(3. <= var3 < 5.)]
-                           #for p in where(float(rnd) <= var3 < float(rnd+3))]
-                           #for p in where(rnd <= var3 < rnd+3)]
-                           for p in where(rnd <= var3 < rnd+chunksize)]
-                           # for p in where(1000.-i <= var3 < 1000.+i)]
-                           # for p in where(100*i <= var3 < 100*(i+1))]
-                #print "time for complete selection-->", time.time()-t1
-                #print "results-->", results, rnd
+                           for p in where('(rnd <= var3) & (var3 < val)')]
             else:
                 results = [p.nrow for p in table
-                           # if p["var3"] < 5.]
-                           #if 3. <= p["var3"] < 5.]
-                           #if float(rnd) <= p["var3"] < float(rnd+3)]
-                           if float(rnd) <= p["var3"] < float(rnd+chunksize)]
-                           # if 1000.-i <= p["var3"] < 1000.+i]
-                           # if 100*i <= p["var3"] < 100*(i+1)]
+                           if float(rnd) <= p["var3"] < float(val)]
         else:
             raise ValueError, "Value for atom '%s' not supported." % atom
         rowselected += len(results)
@@ -349,7 +306,7 @@ def readFile(filename, atom, riter, indexmode, verbose):
 
     return (rowsread, rowselected, rowsize, time1, time2, tcpu1, tcpu2)
 
-def benchSearch(file, riter, indexmode, bfile, heavy, psyco, verbose):
+def benchSearch(file, riter, indexmode, bfile, heavy, psyco, dselect, verbose):
 
     # Open the benchfile in append mode
     bf = openFile(bfile,"a")
@@ -370,18 +327,19 @@ def benchSearch(file, riter, indexmode, bfile, heavy, psyco, verbose):
         tablepath = tableparent + atom
         table = bf.getNode(tablepath)
         (rowsr, rowsel, rowssz, time1, time2, tcpu1, tcpu2) = \
-                readFile(file, atom, riter, indexmode, verbose)
-        table.row["nrows"] = rowsr
-        table.row["rowsel"] = rowsel
+                readFile(file, atom, riter, indexmode, dselect, verbose)
+        row = table.row
+        row["nrows"] = rowsr
+        row["rowsel"] = rowsel
         treadrows = round(time1, 6)
-        table.row["time1"] = time1
+        row["time1"] = time1
         treadrows2 = round(time2, 6)
-        table.row["time2"] = time2
+        row["time2"] = time2
         cpureadrows = round(tcpu1, 6)
-        table.row["tcpu1"] = tcpu1
+        row["tcpu1"] = tcpu1
         cpureadrows2 = round(tcpu2, 6)
-        table.row["tcpu2"] = tcpu2
-        table.row["psyco"] = psyco
+        row["tcpu2"] = tcpu2
+        row["psyco"] = psyco
         tpercent = int(round(cpureadrows/treadrows, 2)*100)
         if riter > 1:
             tpercent2 = int(round(cpureadrows2/treadrows2, 2)*100)
@@ -399,17 +357,18 @@ def benchSearch(file, riter, indexmode, bfile, heavy, psyco, verbose):
                   (treadrows2, cpureadrows2, tpercent2)
         #rowsec1 = round(rowsr / float(treadrows), 6)/10**6
         rowsec1 = rowsr / treadrows
-        table.row["rowsec1"] = rowsec1
+        row["rowsec1"] = rowsec1
         print "Read Mrows/sec: ",
         print round(rowsec1 / 10.**6, 6), "(first time)",
         if riter > 1:
             rowsec2 = rowsr / treadrows2
-            table.row["rowsec2"] = rowsec2
+            row["rowsec2"] = rowsec2
             print round(rowsec2 / 10.**6, 6), "(cache time)"
         else:
             print
         # Append the info to the table
-        table.row.append()
+        row.append()
+        table.flush()
     # Close the benchmark file
     bf.close()
 
@@ -425,10 +384,9 @@ if __name__=="__main__":
 
     import time
 
-    usage = """usage: %s [-v] [-p] [-a] [-r] [-w] [-c level] [-l complib] [-S] [-F] [-n nrows] [-x] [-b file] [-t] [-h] [-k riter] [-m indexmode] datafile
+    usage = """usage: %s [-v] [-p] [-R] [-r] [-w] [-c level] [-l complib] [-S] [-F] [-n nrows] [-x] [-b file] [-t] [-h] [-k riter] [-m indexmode] [-N range] [-d range] datafile
             -v verbose
             -p use "psyco" if available
-            -a automatic indexing (default is separate indexing)
             -R use Random values for filling
             -r only read test
             -w only write test
@@ -442,10 +400,12 @@ if __name__=="__main__":
             -t worsT searching case
             -h heavy benchmark (operations without strings)
             -m index mode for reading ("indexed" | "inkernel" | "standard")
+            -N introduce (uniform) noise within range into the values
+            -d the interval for look values (int, float) at. Default is 3.
             -k number of iterations for reading\n""" % sys.argv[0]
 
     try:
-        opts, pargs = getopt.getopt(sys.argv[1:], 'vpaSFRrowxthk:b:c:l:n:m:')
+        opts, pargs = getopt.getopt(sys.argv[1:], 'vpSFRrowxthk:b:c:l:n:m:N:d:')
     except:
         sys.stderr.write(usage)
         sys.exit(0)
@@ -456,8 +416,9 @@ if __name__=="__main__":
         sys.exit(0)
 
     # default options
+    dselect = 3.
+    noise = 0.
     verbose = 0
-    auto = 0
     fieldName = None
     testread = 1
     testwrite = 1
@@ -470,8 +431,8 @@ if __name__=="__main__":
     index = 1
     heavy = 0
     bfile = "bench.h5"
-    supported_imodes = ["indexed","inkernel","standard"]
-    indexmode = "indexed"
+    supported_imodes = ["indexed", "inkernel", "standard"]
+    indexmode = "inkernel"
     riter = 1
 
     # Get the options
@@ -480,8 +441,6 @@ if __name__=="__main__":
             verbose = 1
         if option[0] == '-p':
             usepsyco = 1
-        if option[0] == '-a':
-            auto = 1
         if option[0] == '-R':
             randomvalues = 1
         if option[0] == '-S':
@@ -510,7 +469,10 @@ if __name__=="__main__":
                 raise ValueError, "Indexmode should be any of '%s' and you passed '%s'" % (supported_imodes, indexmode)
         elif option[0] == '-n':
             nrows = int(float(option[1])*1000)
-            #nrows = int(float(option[1])*1024)
+        elif option[0] == '-N':
+            noise = float(option[1])
+        elif option[0] == '-d':
+            dselect = float(option[1])
         elif option[0] == '-k':
             riter = int(option[1])
 
@@ -542,9 +504,10 @@ if __name__=="__main__":
                     print "Suffling..."
         if psyco_imported and usepsyco:
             psyco.bind(createFile)
-        benchCreate(file, nrows, filters, index, bfile, heavy, auto,
-                    usepsyco, verbose)
+        benchCreate(file, nrows, filters, index, bfile, heavy,
+                    usepsyco, noise, verbose)
     if testread:
         if psyco_imported and usepsyco:
             psyco.bind(readFile)
-        benchSearch(file, riter, indexmode, bfile, heavy, usepsyco, verbose)
+        benchSearch(file, riter, indexmode, bfile, heavy, usepsyco,
+                    dselect, verbose)
