@@ -1,4 +1,4 @@
-from numarray import *
+from numpy import *
 from tables import *
 
 # Open a new empty HDF5 file
@@ -7,7 +7,7 @@ fileh = openFile("attributes1.h5", mode = "w", title="Testing attributes")
 root = fileh.root
 
 # Create an array
-a = array([1, 2, 4], Int32)
+a = array([1, 2, 4], int32)
 # Save it on the HDF5 file
 hdfarray = fileh.createArray(root, 'array', a, "Integer array")
 
