@@ -1,9 +1,9 @@
 from tables import *
 
 class Particle(IsDescription):
-    identity = StringCol(length=22, dflt=" ", pos = 0)  # character String
-    idnumber = Int16Col(1, pos = 1)  # short integer
-    speed    = Float32Col(1, pos = 1)  # single-precision
+    identity = StringCol(itemsize=22, dflt=" ", pos=0)  # character String
+    idnumber = Int16Col(dflt=1, pos = 1)  # short integer
+    speed    = Float32Col(dflt=1, pos = 1)  # single-precision
 
 # Open a file in "w"rite mode
 fileh = openFile("objecttree.h5", mode = "w")
