@@ -2,7 +2,6 @@
 #include "tables.h"
 #include "utils.h"
 #include "H5Zlzo.h"  		       /* Import FILTER_LZO */
-#include "H5Zucl.h"  		       /* Import FILTER_UCL */
 #include "H5Zbzip2.h"  		       /* Import FILTER_BZIP2 */
 #include <string.h>
 #include <stdlib.h>
@@ -33,10 +32,8 @@ herr_t H5VLARRAYmake( hid_t loc_id,
 		      const char *dset_name,
 		      const char *class_,
 		      const char *title,
-		      const char *flavor,
 		      const char *obversion,    /* The Array VERSION number */
 		      const int rank,
-		      const int scalar,
 		      const hsize_t *dims,
 		      hid_t type_id,
 		      hsize_t chunk_size,
@@ -71,7 +68,7 @@ herr_t H5VLARRAYmake( hid_t loc_id,
  vldata.len = 1;		/* Only one array type to save */
 
  /* Create a VL datatype */
- if (scalar == 1) {
+ if (rank == 0) {
    datatype = H5Tvlen_create(type_id);
  }
  else {
@@ -117,11 +114,6 @@ herr_t H5VLARRAYmake( hid_t loc_id,
      if ( H5Pset_filter( plist_id, FILTER_LZO, H5Z_FLAG_OPTIONAL, 3, cd_values) < 0 )
        return -1;
    }
-   /* The UCL compress does accept parameters */
-   else if (strcmp(complib, "ucl") == 0) {
-     if ( H5Pset_filter( plist_id, FILTER_UCL, H5Z_FLAG_OPTIONAL, 3, cd_values) < 0 )
-       return -1;
-   }
    /* The bzip2 compress does accept parameters */
    else if (strcmp(complib, "bzip2") == 0) {
      if ( H5Pset_filter( plist_id, FILTER_BZIP2, H5Z_FLAG_OPTIONAL, 3, cd_values) < 0 )
@@ -164,10 +156,6 @@ herr_t H5VLARRAYmake( hid_t loc_id,
  if ( H5ATTRset_attribute_string( dataset_id, "CLASS", class_ ) < 0 )
   goto out;
 
- /* Attach the CLASS attribute */
- if ( H5ATTRset_attribute_string( dataset_id, "FLAVOR", flavor ) < 0 )
-  goto out;
-
  /* Attach the VERSION attribute */
  if ( H5ATTRset_attribute_string( dataset_id, "VERSION", obversion ) < 0 )
   goto out;
@@ -451,7 +439,7 @@ herr_t H5VLARRAYget_info( hid_t   dataset_id,
     get_order(*base_type_id, base_byteorder);
   }
   else {
-    strcpy(base_byteorder, "non-relevant");
+    strcpy(base_byteorder, "irrelevant");
   }
 
   return 0;
