@@ -10,7 +10,7 @@
 #endif
 #ifdef HAVE_LZO2_LIB
 #   include "lzo/lzo1x.h"
-#   define HAVE_LZO_LIB  /* The API for LZO and LZO2 are mostly identical */
+#   define HAVE_LZO_LIB  /* The API for LZO and LZO2 is mostly identical */
 #endif
 
 /* #undef DEBUG */
@@ -27,7 +27,7 @@
 
 */
 
-/* Ok. from pytables 0.8 on I decided to let the user select the
+/* From pytables 0.8 on I decided to let the user select the
    fletcher32 checksum provided in HDF5 1.6 or higher. So, even though
    the CHECKSUM support here seems pretty stable it will be disabled.
    F. Altet 2004/01/02 */
@@ -65,8 +65,12 @@ int register_lzo(char **version, char **date) {
 #endif /* if H5_VERSION < "1.7" */
 
   /* Init the LZO library */
-  if (lzo_init()!=LZO_E_OK)
+  if (lzo_init()!=LZO_E_OK) {
     fprintf(stderr, "Problems initializing LZO library\n");
+    *version = NULL;
+    *date = NULL;
+    return 0; /* lib is not available */
+  }
 
   /* Register the lzo compressor */
   H5Zregister(&filter_class);
