@@ -1,6 +1,6 @@
-#include <Python.h>
-#include <numarray/numarray.h>
-#include <hdf5.h>
+#include "Python.h"
+#include "numpy/arrayobject.h"
+#include "hdf5.h"
 
 /* Define this variable for error printings */
 /*#define DEBUG 1 */
@@ -84,7 +84,8 @@ size_t get_complex_precision(hid_t type_id);
 
 herr_t get_order(hid_t type_id, char *byteorder);
 
-hid_t create_native_complex64(const char *byteorder);
+hid_t create_ieee_complex64(const char *byteorder);
 
-hid_t create_native_complex32(const char *byteorder);
+hid_t create_ieee_complex128(const char *byteorder);
 
+hsize_t get_len_of_range(hsize_t lo, hsize_t hi, hsize_t step);
