@@ -5,7 +5,7 @@ Classes for describing columns for ``Table`` objects.
 :Contact: faltet at carabos dot com
 :License: BSD
 :Created: September 21, 2002
-:Revision: $Id: description.py 2745 2007-04-22 11:09:35Z ivilata $
+:Revision: $Id: description.py 3231 2007-09-12 11:03:14Z ivilata $
 
 Variables
 =========
@@ -33,7 +33,7 @@ from tables.path import checkNameValidity
 __docformat__ = 'reStructuredText'
 """The format of documentation strings in this module."""
 
-__version__ = '$Revision: 2745 $'
+__version__ = '$Revision: 3231 $'
 """Repository version of this file."""
 
 
@@ -132,7 +132,7 @@ class Col(atom.Atom):
         return colclass(pos=pos, **kwargs)
 
     @classmethod
-    def from_sctype(class_, sctype, shape=1, dflt=None, pos=None):
+    def from_sctype(class_, sctype, shape=(), dflt=None, pos=None):
         """
         Create a `Col` definition from a NumPy scalar type `sctype`.
 
@@ -159,7 +159,7 @@ class Col(atom.Atom):
         return class_.from_atom(newatom, pos=pos)
 
     @classmethod
-    def from_type(class_, type, shape=1, dflt=None, pos=None):
+    def from_type(class_, type, shape=(), dflt=None, pos=None):
         """
         Create a `Col` definition from a PyTables `type`.
 
@@ -170,7 +170,7 @@ class Col(atom.Atom):
         return class_.from_atom(newatom, pos=pos)
 
     @classmethod
-    def from_kind(class_, kind, itemsize=None, shape=1, dflt=None, pos=None):
+    def from_kind(class_, kind, itemsize=None, shape=(), dflt=None, pos=None):
         """
         Create a `Col` definition from a PyTables `kind`.
 
