@@ -4,7 +4,7 @@
 #       Created:        September 4, 2002
 #       Author:  Francesc Altet - faltet@carabos.com
 #
-#       $Id: file.py 2964 2007-05-30 12:27:55Z faltet $
+#       $Id: file.py 3323 2007-11-20 16:55:50Z ivilata $
 #
 ########################################################################
 
@@ -74,7 +74,7 @@ else:
 
 
 
-__version__ = "$Revision: 2964 $"
+__version__ = "$Revision: 3323 $"
 
 
 #format_version = "1.0" # Initial format
@@ -341,6 +341,10 @@ class File(hdf5Extension.File, object):
     The Undo/Redo mechanism is persistent between sessions and can only
     be disabled by calling the `disableUndo()` method.
 
+    File objects can also act as context managers when using the
+    ``with`` statement introduced in Python 2.5.  When exiting a
+    context, the file is automatically closed.
+
     Public instance variables
     -------------------------
 
@@ -374,6 +378,8 @@ class File(hdf5Extension.File, object):
     * close()
     * copyFile(dstfilename[, overwrite][, **kwargs])
     * flush()
+    * __enter__()
+    * __exit__([*exc_info])
     * __str__()
     * __repr__()
 
@@ -2084,6 +2090,15 @@ Mark ``%s`` is older than the current mark. Use `redo()` or `goto()` instead."""
         # Delete the entry in the dictionary of opened files
         del _open_files[self]
 
+    def __enter__(self):
+        """Enter a context and return the same file."""
+        return self
+
+    def __exit__(self, *exc_info):
+        """Exit a context and close the file."""
+        self.close()
+        return False  # do not hide exceptions
+
     def __str__(self):
         """
         Return a short string representation of the object tree.
@@ -2209,6 +2224,27 @@ Mark ``%s`` is older than the current mark. Use `redo()` or `goto()` instead."""
 
         return node
 
+
+    def _updateNodeLocations(self, oldPath, newPath):
+        """
+        Update location information of nodes under `oldPath`.
+
+        This only affects *already loaded* nodes.
+        """
+        oldPrefix = oldPath + '/'  # root node can not be renamed, anyway
+        oldPrefixLen = len(oldPrefix)
+
+        # Update alive and dead descendents.
+        for cache in [self._aliveNodes, self._deadNodes]:
+            for nodePath in cache:
+                if nodePath.startswith(oldPrefix):
+                    nodeSuffix = nodePath[oldPrefixLen:]
+                    newNodePath = joinPath(newPath, nodeSuffix)
+                    newNodePPath = splitPath(newNodePath)[0]
+                    descendentNode = self._getNode(nodePath)
+                    descendentNode._g_updateLocation(newNodePPath)
+
+
 # If a user hits ^C during a run, it is wise to gracefully close the opened files.
 def close_open_files():
     are_open_files = len(_open_files) > 0
