@@ -4,7 +4,7 @@
 #       Created: September 4, 2002
 #       Author:  Francesc Altet - faltet@carabos.com
 #
-#       $Id: group.py 3331 2007-11-21 18:42:05Z ivilata $
+#       $Id: group.py 3398 2008-01-11 17:26:06Z faltet $
 #
 ########################################################################
 
@@ -49,7 +49,7 @@ from tables.attributeset import AttributeSet
 
 
 
-__version__ = "$Revision: 3331 $"
+__version__ = "$Revision: 3398 $"
 
 obversion = "1.0"
 
@@ -944,10 +944,8 @@ be ready to see PyTables asking for *lots* of memory and possibly slow I/O."""
         from this group *before* closing it.
         """
 
-        if not hasattr(self, "_v_isopen"):
-            return  # the node is probably being aborted during creation time
         if not self._v_isopen:
-            return  # the node is already closed
+            return  # the node is already closed or not initialized
 
         # hdf5Extension operations:
         #   Close HDF5 group.
