@@ -4,7 +4,7 @@
 #       Created: October 14, 2002
 #       Author:  Francesc Altet - faltet@carabos.com
 #
-#       $Id: leaf.py 3334 2007-11-22 16:56:15Z faltet $
+#       $Id: leaf.py 3398 2008-01-11 17:26:06Z faltet $
 #
 ########################################################################
 
@@ -29,6 +29,7 @@ Misc variables:
 
 import sys
 import warnings
+import math
 
 import numpy
 
@@ -45,7 +46,25 @@ from tables.exceptions import PerformanceWarning
 
 
 
-__version__ = "$Revision: 3334 $"
+__version__ = "$Revision: 3398 $"
+
+
+def csformula(expectedsizeinMB):
+    """Return the fitted chunksize for expectedsizeinMB."""
+    # For a basesize of 8 KB, this will return:
+    # 8 KB for datasets <= 1 MB
+    # 1 MB for datasets >= 10 TB
+    basesize = 8*1024   # 8 KB is a good minimum
+    return basesize * int(2**math.log10(expectedsizeinMB))
+
+
+def limit_es(expectedsizeinMB):
+    """Protection against creating too small or too large chunks."""
+    if expectedsizeinMB < 1:        # < 1 MB
+        expectedsizeinMB = 1
+    elif expectedsizeinMB > 10**7:  # > 10 TB
+        expectedsizeinMB = 10**7
+    return expectedsizeinMB
 
 
 def calc_chunksize(expectedsizeinMB):
@@ -64,29 +83,10 @@ def calc_chunksize(expectedsizeinMB):
     always, your mileage may vary.
     """
 
-    basesize = 1024*4   # 4KB is one page of memory
-    if expectedsizeinMB < 1:
-        # Values for files less than 1 MB of size
-        chunksize = basesize
-    elif (expectedsizeinMB >= 1 and
-        expectedsizeinMB < 10):
-        # Values for files between 1 MB and 10 MB
-        chunksize = 2 * basesize
-    elif (expectedsizeinMB >= 10 and
-          expectedsizeinMB < 100):
-        # Values for sizes between 10 MB and 100 MB
-        chunksize = 4 * basesize
-    elif (expectedsizeinMB >= 100 and
-          expectedsizeinMB < 1000):
-        # Values for sizes between 100 MB and 1 GB
-        chunksize = 8 * basesize
-    elif (expectedsizeinMB >= 1000 and
-          expectedsizeinMB < 10000):
-        # Values for sizes between 1 GB and 10 GB
-        chunksize = 16 * basesize
-    else:  # Greater than 10 GB
-        chunksize = 32 * basesize
-
+    expectedsizeinMB = limit_es(expectedsizeinMB)
+    zone = int(math.log10(expectedsizeinMB))
+    expectedsizeinMB = 10**zone
+    chunksize = csformula(expectedsizeinMB)
     return chunksize
 
 
@@ -666,10 +666,8 @@ very small/large chunksize, you may want to increase/decrease it."""
         flush pending data to disk or not before closing.
         """
 
-        if not hasattr(self, "_v_isopen"):
-            return  # the node is probably being aborted during creation time
         if not self._v_isopen:
-            return  # the node is already closed
+            return  # the node is already closed or not initialized
 
         if flush:
             self.flush()
