@@ -6,7 +6,7 @@ Base class for PyTables nodes
 :Contact:  ivilata@carabos.com
 :Created:  2005-02-11
 :License:  BSD
-:Revision: $Id: node.py 3331 2007-11-21 18:42:05Z ivilata $
+:Revision: $Id: node.py 3398 2008-01-11 17:26:06Z faltet $
 
 
 Classes:
@@ -39,7 +39,7 @@ from tables.attributeset import AttributeSet, NotLoggedAttributeSet
 __docformat__ = 'reStructuredText'
 """The format of documentation strings in this module."""
 
-__version__ = '$Revision: 3331 $'
+__version__ = '$Revision: 3398 $'
 """Repository version of this file."""
 
 
@@ -151,8 +151,6 @@ class Node(object):
         The hosting `File` instance.
     _v_hdf5name
         The name of this node in the hosting HDF5 file (a string).
-    _v_isopen
-        Whether this node is open or not.
     _v_name
         The name of this node in its parent group (a string).
     _v_parent
@@ -165,6 +163,8 @@ class Node(object):
 
     _v_attrs
         The associated `AttributeSet` instance.
+    _v_isopen
+        Whether this node is open or not.
     _v_objectID
         A node identifier (may change from run to run).
 
@@ -244,6 +244,10 @@ class Node(object):
 
     # </properties>
 
+    # This may be looked up by ``__del__`` when ``__init__`` doesn't get
+    # to be called.  See ticket #144 for more info.
+    _v_isopen = False
+    """The default class attribute for _v_isopen."""
 
     # The ``_log`` argument is only meant to be used by ``_g_copyAsChild()``
     # to avoid logging the creation of children nodes of a copied sub-tree.
@@ -340,10 +344,8 @@ class Node(object):
         #    revived, the user would also need to force the closed
         #    `Node` out of memory, which is not a trivial task.
         #
-        if not hasattr(self, "_v_isopen"):
-            return  # the node is probably being aborted during creation time
         if not self._v_isopen:
-            return  # the node is already closed
+            return  # the node is already closed or not initialized
 
         # If we get here, the `Node` is still open.
         file_ = self._v_file
