@@ -5,26 +5,26 @@
 #	Author:  Ivan Vilata i Balaguer - reverse:net.selidor@ivan
 #
 #	$Source: /home/ivan/_/programari/pytables/svn/cvs/pytables/pytables/tables/nodes/__init__.py,v $
-#	$Id: __init__.py 714 2005-03-10 16:08:59Z ivilata $
+#	$Id: __init__.py 2381 2007-02-16 18:06:40Z ivilata $
 #
 ########################################################################
 
 """Special node behaviours for PyTables.
 
 This package contains several modules that give specific behaviours
-to PyTables nodes.  For instance, the FileNode module provides
+to PyTables nodes.  For instance, the filenode module provides
 a file interface to a PyTables node.
 
 
 Package modules:
-	FileNode -- A file interface to nodes for PyTables databases.
+	filenode -- A file interface to nodes for PyTables databases.
 """
 
 # Revision for the package initialization code.
-__revision__ = '$Id: __init__.py 714 2005-03-10 16:08:59Z ivilata $'
+__revision__ = '$Id: __init__.py 2381 2007-02-16 18:06:40Z ivilata $'
 
 # The list of names to be exported to the importing module.
-__all__ = ['FileNode']
+__all__ = ['filenode']
 
 
 
