@@ -1,29 +1,35 @@
 import new
-from numpy import *
+from numpy import array, arange, sin, zeros, sum, int32, empty, \
+     prod, uint16, complex_, float64, rec
 from numpy.testing import *
+from numpy import shape, allclose, ravel
+
 
 from tables.numexpr import E, numexpr, evaluate, disassemble
 
-class test_numexpr(NumpyTestCase):
-    def check_simple(self):
+
+TestCase = NumpyTestCase
+
+class test_numexpr(TestCase):
+    def test_simple(self):
         ex = 2.0 * E.a + 3.0 * E.b * E.c
         func = numexpr(ex, signature=[('a', float), ('b', float), ('c', float)])
         x = func(array([1., 2, 3]), array([4., 5, 6]), array([7., 8, 9]))
         assert_array_equal(x, array([  86.,  124.,  168.]))
 
-    def check_simple_expr_small_array(self):
+    def test_simple_expr_small_array(self):
         func = numexpr(E.a)
         x = arange(100.0)
         y = func(x)
         assert_array_equal(x, y)
 
-    def check_simple_expr(self):
+    def test_simple_expr(self):
         func = numexpr(E.a)
         x = arange(1e5)
         y = func(x)
         assert_array_equal(x, y)
 
-    def check_rational_expr(self):
+    def test_rational_expr(self):
         func = numexpr((E.a + 2.0*E.b) / (1 + E.a + 4*E.b*E.b))
         a = arange(1e5)
         b = arange(1e5) * 0.1
@@ -31,7 +37,7 @@ class test_numexpr(NumpyTestCase):
         y = func(a, b)
         assert_array_equal(x, y)
 
-    def check_reductions(self):
+    def test_reductions(self):
         # Check that they compile OK.
         assert_equal(disassemble(numexpr("sum(x**2+2, axis=None)", [('x', float)])),
                     [('mul_fff', 't3', 'r1[x]', 'r1[x]'),
@@ -70,7 +76,7 @@ class test_numexpr(NumpyTestCase):
         assert_equal(evaluate("sum(x**2+2,axis=0)"), sum(x**2+2,axis=0))
         assert_equal(evaluate("prod(x**2+2,axis=0)"), prod(x**2+2,axis=0))
 
-    def check_axis(self):
+    def test_axis(self):
         y = arange(9.0).reshape(3,3)
         try:
             evaluate("sum(y, axis=2)")
@@ -88,37 +94,37 @@ class test_numexpr(NumpyTestCase):
 
 
 
-    def check_r0_reuse(self):
+    def test_r0_reuse(self):
         assert_equal(disassemble(numexpr("x**2+2", [('x', float)])),
                     [('mul_fff', 'r0', 'r1[x]', 'r1[x]'),
                      ('add_fff', 'r0', 'r0', 'c2[2.0]')])
 
-class test_evaluate(NumpyTestCase):
-    def check_simple(self):
+class test_evaluate(TestCase):
+    def test_simple(self):
         a = array([1., 2., 3.])
         b = array([4., 5., 6.])
         c = array([7., 8., 9.])
         x = evaluate("2*a + 3*b*c")
         assert_array_equal(x, array([  86.,  124.,  168.]))
 
-    def check_simple_expr_small_array(self):
+    def test_simple_expr_small_array(self):
         x = arange(100.0)
         y = evaluate("x")
         assert_array_equal(x, y)
 
-    def check_simple_expr(self):
+    def test_simple_expr(self):
         x = arange(1e5)
         y = evaluate("x")
         assert_array_equal(x, y)
 
-    def check_rational_expr(self):
+    def test_rational_expr(self):
         a = arange(1e5)
         b = arange(1e5) * 0.1
         x = (a + 2*b) / (1 + a + 4*b*b)
         y = evaluate("(a + 2*b) / (1 + a + 4*b*b)")
         assert_array_equal(x, y)
 
-    def check_complex_expr(self):
+    def test_complex_expr(self):
         def complex(a, b):
             c = zeros(a.shape, dtype=complex_)
             c.real = a
@@ -133,7 +139,7 @@ class test_evaluate(NumpyTestCase):
         assert_array_almost_equal(x, y)
 
 
-    def check_complex_strides(self):
+    def test_complex_strides(self):
         a = arange(100).reshape(10,10)[::2]
         b = arange(50).reshape(5,10)
         assert_array_equal(evaluate("a+b"), a+b)
@@ -146,7 +152,7 @@ class test_evaluate(NumpyTestCase):
         assert_array_equal(evaluate("a0+c1"), a0+c1)
 
 
-    def check_broadcasting(self):
+    def test_broadcasting(self):
         a = arange(100).reshape(10,10)[::2]
         c = arange(10)
         d = arange(5).reshape(5,1)
@@ -155,20 +161,20 @@ class test_evaluate(NumpyTestCase):
         expr = numexpr("2.0*a+3.0*c",[('a',float),('c', float)])
         assert_array_equal(expr(a,c), 2.0*a+3.0*c)
 
-    def check_all_scalar(self):
+    def test_all_scalar(self):
         a = 3.
         b = 4.
         assert_equal(evaluate("a+b"), a+b)
         expr = numexpr("2*a+3*b",[('a',float),('b', float)])
         assert_equal(expr(a,b), 2*a+3*b)
 
-    def check_run(self):
+    def test_run(self):
         a = arange(100).reshape(10,10)[::2]
         b = arange(10)
         expr = numexpr("2*a+3*b",[('a',float),('b', float)])
         assert_array_equal(expr(a,b), expr.run(a,b))
 
-    def check_illegal_value(self):
+    def test_illegal_value(self):
         a = arange(3)
         try:
             evaluate("a < [0, 0, 0]")
@@ -237,13 +243,13 @@ def equal(a, b, exact):
 
 class Skip(Exception): pass
 
-class test_expressions(NumpyTestCase):
+class test_expressions(TestCase):
     pass
 
-def generate_check_expressions():
+def generate_test_expressions():
     test_no = [0]
-    def make_check_method(a, a2, b, c, d, e, x, expr,
-                          test_scalar, dtype, optimization, exact):
+    def make_test_method(a, a2, b, c, d, e, x, expr,
+                         test_scalar, dtype, optimization, exact):
         this_locals = locals()
         def method(self):
             try:
@@ -267,7 +273,7 @@ def generate_check_expressions():
                 self.warn('numexpr error for expression %r' % (expr,))
                 raise
         test_no[0] += 1
-        name = 'check_%04d' % (test_no[0],)
+        name = 'test_%04d' % (test_no[0],)
         setattr(test_expressions, name,
                 new.instancemethod(method, None, test_expressions))
     x = None
@@ -298,27 +304,27 @@ def generate_check_expressions():
                             continue # skip complex comparisons
                         if dtype in (int, long) and test_scalar and expr == '(a+1) ** -1':
                             continue
-                        make_check_method(a, a2, b, c, d, e, x,
-                                          expr, test_scalar, dtype,
-                                          optimization, exact)
+                        make_test_method(a, a2, b, c, d, e, x,
+                                         expr, test_scalar, dtype,
+                                         optimization, exact)
 
-generate_check_expressions()
+generate_test_expressions()
 
-class test_int32_int64(NumpyTestCase):
-    def check_small_long(self):
+class test_int32_int64(TestCase):
+    def test_small_long(self):
         # Small longs should not be downgraded to ints.
         res = evaluate('42L')
         assert_array_equal(res, 42)
         self.assertEqual(res.dtype.name, 'int64')
 
-    def check_big_int(self):
+    def test_big_int(self):
         # Big ints should be promoted to longs.
         # This test may only fail under 64-bit platforms.
         res = evaluate('2**40')
         assert_array_equal(res, 2**40)
         self.assertEqual(res.dtype.name, 'int64')
 
-    def check_long_constant_promotion(self):
+    def test_long_constant_promotion(self):
         int32array = arange(100, dtype='int32')
         res = int32array * 2
         res32 = evaluate('int32array * 2')
@@ -328,7 +334,7 @@ class test_int32_int64(NumpyTestCase):
         self.assertEqual(res32.dtype.name, 'int32')
         self.assertEqual(res64.dtype.name, 'int64')
 
-    def check_int64_array_promotion(self):
+    def test_int64_array_promotion(self):
         int32array = arange(100, dtype='int32')
         int64array = arange(100, dtype='int64')
         respy = int32array * int64array
@@ -336,7 +342,7 @@ class test_int32_int64(NumpyTestCase):
         assert_array_equal(respy, resnx)
         self.assertEqual(resnx.dtype.name, 'int64')
 
-class test_strings(NumpyTestCase):
+class test_strings(TestCase):
     BLOCK_SIZE1 = 128
     BLOCK_SIZE2 = 8
     str_list1 = ['foo', 'bar', '', '  ']
@@ -346,7 +352,7 @@ class test_strings(NumpyTestCase):
     str_array2 = array(str_list2 * str_nloops)
     str_constant = 'doodoo'
 
-    def check_null_chars(self):
+    def test_null_chars(self):
         str_list = [
             '\0\0\0', '\0\0foo\0', '\0\0foo\0b', '\0\0foo\0b\0',
             'foo\0', 'foo\0b', 'foo\0b\0', 'foo\0bar\0baz\0\0' ]
@@ -354,14 +360,14 @@ class test_strings(NumpyTestCase):
             r = evaluate('s')
             self.assertEqual(s, r.tostring())  # check *all* stored data
 
-    def check_compare_copy(self):
+    def test_compare_copy(self):
         sarr = self.str_array1
         expr = 'sarr'
         res1 = eval(expr)
         res2 = evaluate(expr)
         assert_array_equal(res1, res2)
 
-    def check_compare_array(self):
+    def test_compare_array(self):
         sarr1 = self.str_array1
         sarr2 = self.str_array2
         expr = 'sarr1 >= sarr2'
@@ -369,7 +375,7 @@ class test_strings(NumpyTestCase):
         res2 = evaluate(expr)
         assert_array_equal(res1, res2)
 
-    def check_compare_variable(self):
+    def test_compare_variable(self):
         sarr = self.str_array1
         svar = self.str_constant
         expr = 'sarr >= svar'
@@ -377,20 +383,20 @@ class test_strings(NumpyTestCase):
         res2 = evaluate(expr)
         assert_array_equal(res1, res2)
 
-    def check_compare_constant(self):
+    def test_compare_constant(self):
         sarr = self.str_array1
         expr = 'sarr >= %r' % self.str_constant
         res1 = eval(expr)
         res2 = evaluate(expr)
         assert_array_equal(res1, res2)
 
-    def check_add_string_array(self):
+    def test_add_string_array(self):
         sarr1 = self.str_array1
         sarr2 = self.str_array2
         expr = 'sarr1 + sarr2'
         self.assert_missing_op('add_sss', expr, locals())
 
-    def check_add_numeric_array(self):
+    def test_add_numeric_array(self):
         sarr = self.str_array1
         narr = arange(len(sarr), dtype='int32')
         expr = 'sarr >= narr'
@@ -406,9 +412,9 @@ class test_strings(NumpyTestCase):
         else:
             self.fail(msg)
 
-    def check_compare_prefix(self):
+    def test_compare_prefix(self):
         # Check comparing two strings where one is a prefix of the
-        # other (see PyTables ticket #76).
+        # other.
         for s1, s2 in [ ('foo', 'foobar'), ('foo', 'foo\0bar'),
                         ('foo\0a', 'foo\0bar') ]:
             self.assert_(evaluate('s1 < s2'))
@@ -421,14 +427,14 @@ class test_strings(NumpyTestCase):
         s1, s2 = 'foo', 'foo\0\0'
         self.assert_(evaluate('s1 == s2'))
 
-# Case for testing PyTables ticket #103, i.e. selections in fields
-# which are aligned but whose data length is not an exact multiple of
-# the length of the record.  The following test exposes the problem
-# only in 32-bit machines, because in 64-bit machines 'c2' is
-# unaligned.  However, this should check most platforms where, while
-# not unaligned, 'len(datatype) > boundary_alignment' is fullfilled.
-class test_irregular_stride(NumpyTestCase):
-    def check_select(self):
+# Case for testing selections in fields which are aligned but whose
+# data length is not an exact multiple of the length of the record.
+# The following test exposes the problem only in 32-bit machines,
+# because in 64-bit machines 'c2' is unaligned.  However, this should
+# check most platforms where, while not unaligned, 'len(datatype) >
+# boundary_alignment' is fullfilled.
+class test_irregular_stride(TestCase):
+    def test_select(self):
         f0 = arange(10, dtype=int32)
         f1 = arange(10, dtype=float64)
 
@@ -452,13 +458,13 @@ def suite():
     #heavy = 1  # uncomment this only for testing purposes
 
     for n in range(niter):
-        theSuite.addTest(unittest.makeSuite(test_numexpr, prefix='check'))
-        theSuite.addTest(unittest.makeSuite(test_evaluate, prefix='check'))
-        theSuite.addTest(unittest.makeSuite(test_expressions, prefix='check'))
-        theSuite.addTest(unittest.makeSuite(test_int32_int64, prefix='check'))
-        theSuite.addTest(unittest.makeSuite(test_strings, prefix='check'))
+        theSuite.addTest(unittest.makeSuite(test_numexpr))
+        theSuite.addTest(unittest.makeSuite(test_evaluate))
+        theSuite.addTest(unittest.makeSuite(test_expressions))
+        theSuite.addTest(unittest.makeSuite(test_int32_int64))
+        theSuite.addTest(unittest.makeSuite(test_strings))
         theSuite.addTest(
-            unittest.makeSuite(test_irregular_stride, prefix='check') )
+            unittest.makeSuite(test_irregular_stride) )
 
     return theSuite
 
