@@ -4,7 +4,7 @@
 #       Created: February 10, 2004
 #       Author:  Francesc Alted - falted@pytables.org
 #
-#       $Id: ptrepack.py 3070 2007-07-02 08:20:47Z faltet $
+#       $Id: ptrepack.py 3214 2007-08-28 14:32:50Z faltet $
 #
 ########################################################################
 
@@ -379,10 +379,11 @@ def main():
         filters = None
     else:
         if complevel is None: complevel = 0
-        if complevel > 0 and shuffle is None:
-            shuffle = True
-        else:
-            shuffle = False
+        if shuffle is None:
+            if complevel > 0:
+                shuffle = True
+            else:
+                shuffle = False
         if complib is None: complib = "zlib"
         if fletcher32 is None: fletcher32 = False
         filters = Filters(complevel=complevel, complib=complib,
