@@ -6,7 +6,7 @@ Utilities for PyTables' test suites
 :Contact:  ivilata@carabos.com
 :Created:  2005-05-24
 :License:  BSD
-:Revision: $Id: common.py 2410 2007-02-19 17:42:39Z faltet $
+:Revision: $Id: common.py 3199 2007-08-16 14:33:13Z ivilata $
 """
 
 import unittest
@@ -15,7 +15,6 @@ import os
 import os.path
 import warnings
 import sys
-import popen2
 import time
 
 import numpy
@@ -452,10 +451,8 @@ class ShowMemTime(PyTablesTestCase):
     def test00(self):
         """Showing memory and time consumption."""
 
-        # Build the command to obtain memory info (only for Linux 2.6.x)
-        cmd = "cat /proc/%s/status" % os.getpid()
-        sout, sin = popen2.popen2(cmd)
-        for line in sout:
+        # Obtain memory info (only for Linux 2.6.x)
+        for line in open("/proc/self/status"):
             if line.startswith("VmSize:"):
                 vmsize = int(line.split()[1])
             elif line.startswith("VmRSS:"):
@@ -468,8 +465,6 @@ class ShowMemTime(PyTablesTestCase):
                 vmexe = int(line.split()[1])
             elif line.startswith("VmLib:"):
                 vmlib = int(line.split()[1])
-        sout.close()
-        sin.close()
         print "\nWallClock time:", time.time() - self.tref
         print "Memory usage: ******* %s *******" % self._getName()
         print "VmSize: %7s kB\tVmRSS: %7s kB" % (vmsize, vmrss)
