@@ -3,14 +3,13 @@ import unittest
 import os
 import tempfile
 from Numeric import *
-from tables import *
-from numarray import typeDict, typecode
 
-from common import verbose, allequal, cleanup
-import common
+from tables import *
+from tables.tests import common
+from tables.tests.common import typecode, allequal
 
 # To delete the internal attributes automagically
-unittest.TestCase.tearDown = cleanup
+unittest.TestCase.tearDown = common.cleanup
 
 class BasicTestCase(unittest.TestCase):
     """Basic test for all the supported typecodes present in Numeric.
@@ -19,7 +18,7 @@ class BasicTestCase(unittest.TestCase):
     endiancheck = 0
 
     def WriteRead(self, testArray):
-        if verbose:
+        if common.verbose:
             print '\n', '-=' * 30
             print "Running test for array with typecode '%s'" % \
                   testArray.typecode(),
@@ -48,7 +47,7 @@ class BasicTestCase(unittest.TestCase):
             b = array(b, typecode=a.typecode())
 
         # Compare them. They should be equal.
-        if not allequal(a,b, "numeric") and verbose:
+        if not allequal(a,b, "numeric") and common.verbose:
             print "Write and read arrays differ!"
             print "Array written:", a
             print "Array written shape:", a.shape
@@ -67,14 +66,14 @@ class BasicTestCase(unittest.TestCase):
             # "l" and "i" typecode, and we can consider them the same
             # to all practical effects
             assert (b.typecode() == "l" or b.typecode() == "i")
-            assert self.root.somearray.type == typeDict["l"] or \
-                   self.root.somearray.type == typeDict["i"]
+            # We have to add "N" that represent Int64 in 64-bit platforms
+            assert typecode[self.root.somearray.atom.type] in ["i", "l", "N"]
         elif a.typecode() == "c":
             assert a.typecode() == b.typecode()
-            assert str(self.root.somearray.type) == "CharType"
+            assert self.root.somearray.atom.type == "string"
         else:
             assert a.typecode() == b.typecode()
-            assert typeDict[a.typecode()] ==  self.root.somearray.type
+            assert a.typecode() == typecode[self.root.somearray.atom.type]
 
         assert allequal(a,b, "numeric")
         self.fileh.close()
@@ -97,8 +96,8 @@ class BasicTestCase(unittest.TestCase):
             b = a[()]
         else:
             b = a[::2]
-            # Ensure that this numarray string is non-contiguous
-            assert b.iscontiguous() == 0
+            # Ensure that this Numeric string is non-contiguous
+            assert b.iscontiguous() == False
         self.WriteRead(b)
         return
 
@@ -193,7 +192,7 @@ class GroupsArrayTestCase(unittest.TestCase):
         It also uses arrays ranks which ranges until 10.
         """
 
-        if verbose:
+        if common.verbose:
             print '\n', '-=' * 30
             print "Running %s.test00_iterativeGroups..." % \
                   self.__class__.__name__
@@ -205,17 +204,14 @@ class GroupsArrayTestCase(unittest.TestCase):
         group = fileh.root
 
         # Set the type codes to test
-        # "w" and "u" not tested due to some inconsistencies in charcodes
-        # between numarray and Numeric
-        #typecodes = ["c", 'b', '1', 's', 'w', 'i', 'u', 'l', 'f', 'd']
-        typecodes = ['c', 'b', '1', 's', 'i', 'l', 'f', 'd', 'F', 'D']
+        typecodes = ['c', 'b', '1', 's', 'w', 'i', 'u', 'l', 'f', 'd']
         i = 1
         for typecode in typecodes:
             # Create an array of typecode, with incrementally bigger ranges
             a = ones((2,) * i, typecode)
             # Save it on the HDF5 file
             dsetname = 'array_' + typecode
-            if verbose:
+            if common.verbose:
                 print "Creating dataset:", group._g_join(dsetname)
             hdfarray = fileh.createArray(group, dsetname, a, "Large array")
             # Create a new group
@@ -239,12 +235,12 @@ class GroupsArrayTestCase(unittest.TestCase):
             dset = getattr(group, 'array_' + typecodes[i-1])
             # Get the actual array
             b = dset.read()
-            if not allequal(a,b, "numeric") and verbose:
+            if not allequal(a,b, "numeric") and common.verbose:
                 print "Array a original. Shape: ==>", a.shape
                 print "Array a original. Data: ==>", a
                 print "Info from dataset:", dset._v_pathname
                 print "  shape ==>", dset.shape,
-                print "  type ==> %s" % dset.type
+                print "  dtype ==>", dset.dtype
                 print "Array b read from file. Shape: ==>", b.shape,
                 print ". Type ==> %s" % b.typecode()
 
@@ -280,10 +276,10 @@ class GroupsArrayTestCase(unittest.TestCase):
         # bug getting the shape of the object, that creates lots of
         # problems (segmentation faults, memory faults...)
         minrank = 1
-        # maxrank = 32 # old limit (Numeric <= 22.0)
+        #maxrank = 32 # old limit (Numeric <= 22.0)
         maxrank = 30  # This limit is set in Numeric 23.x and 24.x
 
-        if verbose:
+        if common.verbose:
             print '\n', '-=' * 30
             print "Running %s.test01_largeRankArrays..." % \
                   self.__class__.__name__
@@ -293,12 +289,12 @@ class GroupsArrayTestCase(unittest.TestCase):
         file = "test_array.h5"
         fileh = openFile(file, mode = "w")
         group = fileh.root
-        if verbose:
+        if common.verbose:
             print "Rank array writing progress: ",
         for rank in range(minrank, maxrank + 1):
             # Create an array of integers, with incrementally bigger ranges
             a = ones((1,) * rank, 'i')
-            if verbose:
+            if common.verbose:
                 print "%3d," % (rank),
             fileh.createArray(group, "array", a, "Rank: %s" % rank)
             group = fileh.createGroup(group, 'group' + str(rank))
@@ -310,7 +306,7 @@ class GroupsArrayTestCase(unittest.TestCase):
         # Open the previous HDF5 file in read-only mode
         fileh = openFile(file, mode = "r")
         group = fileh.root
-        if verbose:
+        if common.verbose:
             print
             print "Rank array reading progress: "
         # Get the metadata on the previosly saved arrays
@@ -319,9 +315,9 @@ class GroupsArrayTestCase(unittest.TestCase):
             a = ones((1,) * rank, 'i')
             # Get the actual array
             b = group.array.read()
-            if verbose:
+            if common.verbose:
                 print "%3d," % (rank),
-            if not a.tolist() == b.tolist() and verbose:
+            if not a.tolist() == b.tolist() and common.verbose:
                 print "Info from dataset:", dset._v_pathname
                 print "  Shape: ==>", dset.shape,
                 print "  typecode ==> %c" % dset.typecode
@@ -350,7 +346,7 @@ class GroupsArrayTestCase(unittest.TestCase):
             # Iterate over the next group
             group = fileh.getNode(group, 'group' + str(rank))
 
-        if verbose:
+        if common.verbose:
             print # This flush the stdout buffer
         # Close the file
         fileh.close()
@@ -360,25 +356,25 @@ class GroupsArrayTestCase(unittest.TestCase):
 
 # Test Record class
 class Record(IsDescription):
-    var1  = StringCol(length=4, dflt="abcd")
-    var2  = StringCol(length=1, dflt="a")
-    var3  = BoolCol(1)  # Typecode == '1' in Numeric. 'B' in numarray
-    var4  = Int8Col(1)
-    var5  = UInt8Col(1)
-    var6  = Int16Col(1)
-    var7  = UInt16Col(1)
-    var8  = Int32Col(1)
-    var9  = UInt32Col(1)
-    # Apparently, there is no way to convert a numarray of 64-bits into
-    # Numarray of 64-bits in 32-bit platforms
+    var1  = StringCol(itemsize=4, dflt="abcd")
+    var2  = StringCol(itemsize=1, dflt="a")
+    var3  = BoolCol(dflt=1)
+    var4  = Int8Col(dflt=1)
+    var5  = UInt8Col(dflt=1)
+    var6  = Int16Col(dflt=1)
+    var7  = UInt16Col(dflt=1)
+    var8  = Int32Col(dflt=1)
+    var9  = UInt32Col(dflt=1)
+    # Apparently, there is no way to convert a NumPy of 64-bits into
+    # Numeric of 64-bits in 32-bit platforms
     # See
     # http://aspn.activestate.com/ASPN/Mail/Message/numpy-discussion/2569120
     # Uncomment this makes test breaks on 64-bit platforms 2005-09-23
     #var10 = Int64Col(1)
-    var11 = Float32Col(1.0)
-    var12 = Float64Col(1.0)
-    var13 = Complex32Col((1.+0.j))
-    var14 = Complex64Col((1.+0.j))
+    var11 = Float32Col(dflt=1.0)
+    var12 = Float64Col(dflt=1.0)
+    var13 = ComplexCol(itemsize=8, dflt=(1.+0.j))
+    var14 = ComplexCol(itemsize=16, dflt=(1.+0.j))
 
 
 class TableReadTestCase(common.PyTablesTestCase):
@@ -393,32 +389,31 @@ class TableReadTestCase(common.PyTablesTestCase):
         for i in range(self.nrows):
             table.row.append()  # Fill 100 rows with default values
         fileh.close()
-        self.fileh = openFile(self.file, "r")
+        self.fileh = openFile(self.file, "a")  # allow flavor changes
 
     def tearDown(self):
         self.fileh.close()
         os.remove(self.file)
-        cleanup(self)
+        common.cleanup(self)
 
 
     def test01_readTableChar(self):
         """Checking column conversion into Numeric in read(). Char flavor"""
 
-        self._verboseHeader()
-
         table = self.fileh.root.table
+        table.flavor = "numeric"
         for colname in table.colnames:
-            numcol = table.read(field=colname, flavor="numeric")
-            typecol = table.colstypes[colname]
-            itemsizecol = table.description._v_itemsizes[colname]
+            numcol = table.read(field=colname)
+            typecol = table.coltypes[colname]
+            itemsizecol = table.description._v_dtypes[colname].base.itemsize
             nctypecode = numcol.typecode()
-            if typecol == "CharType":
+            if typecol == "string":
                 if itemsizecol > 1:
                     orignumcol = array(['abcd']*self.nrows, typecode='c')
                 else:
                     orignumcol = array(['a']*self.nrows, typecode='c')
                     orignumcol.shape=(self.nrows,)
-                if verbose:
+                if common.verbose:
                     print "Typecode of Numeric column read:", nctypecode
                     print "Should look like:", 'c'
                     print "Itemsize of column:", itemsizecol
@@ -431,19 +426,18 @@ class TableReadTestCase(common.PyTablesTestCase):
     def test01_readTableNum(self):
         """Checking column conversion into Numeric in read(). Numeric flavor"""
 
-        self._verboseHeader()
-
         table = self.fileh.root.table
+        table.flavor="numeric"
         for colname in table.colnames:
-            numcol = table.read(field=colname, flavor="numeric")
-            typecol = table.colstypes[colname]
+            numcol = table.read(field=colname)
+            typecol = table.coltypes[colname]
             nctypecode = numcol.typecode()
-            if typecol <> "CharType":
-                if typecol == "Int64":
+            if typecol <> "string":
+                if typecol == "int64":
                     return
-                if typecol == "Bool":
+                if typecol == "bool":
                     nctypecode = "B"
-                if verbose:
+                if common.verbose:
                     print "Typecode of Numeric column read:", nctypecode
                     print "Should look like:", typecode[typecol]
                 orignumcol = ones(shape=self.nrows, typecode=numcol.typecode())
@@ -454,24 +448,22 @@ class TableReadTestCase(common.PyTablesTestCase):
     def test02_readCoordsChar(self):
         """Column conversion into Numeric in readCoords(). Chars"""
 
-        self._verboseHeader()
-
         table = self.fileh.root.table
+        table.flavor = "numeric"
         coords = (1,2,3)
         self.nrows = len(coords)
         for colname in table.colnames:
-            numcol = table.readCoordinates(coords, field=colname,
-                                           flavor="numeric")
-            typecol = table.colstypes[colname]
-            itemsizecol = table.description._v_itemsizes[colname]
+            numcol = table.readCoordinates(coords, field=colname)
+            typecol = table.coltypes[colname]
+            itemsizecol = table.description._v_dtypes[colname].base.itemsize
             nctypecode = numcol.typecode()
-            if typecol == "CharType":
+            if typecol == "string":
                 if itemsizecol > 1:
                     orignumcol = array(['abcd']*self.nrows, typecode='c')
                 else:
                     orignumcol = array(['a']*self.nrows, typecode='c')
                     orignumcol.shape=(self.nrows,)
-                if verbose:
+                if common.verbose:
                     print "Typecode of Numeric column read:", nctypecode
                     print "Should look like:", 'c'
                     print "Itemsize of column:", itemsizecol
@@ -484,22 +476,20 @@ class TableReadTestCase(common.PyTablesTestCase):
     def test02_readCoordsNum(self):
         """Column conversion into Numeric in readCoordinates(). Numerical"""
 
-        self._verboseHeader()
-
         table = self.fileh.root.table
+        table.flavor = "numeric"
         coords = (1,2,3)
         self.nrows = len(coords)
         for colname in table.colnames:
-            numcol = table.readCoordinates(coords, field=colname,
-                                           flavor="numeric")
-            typecol = table.colstypes[colname]
+            numcol = table.readCoordinates(coords, field=colname)
+            typecol = table.coltypes[colname]
             nctypecode = numcol.typecode()
-            if typecol <> "CharType":
-                if typecol == "Int64":
+            if typecol <> "string":
+                if typecol == "int64":
                     return
-                if typecol == "Bool":
+                if typecol == "bool":
                     nctypecode = "B"
-                if verbose:
+                if common.verbose:
                     print "Typecode of Numeric column read:", nctypecode
                     print "Should look like:", typecode[typecol]
                 orignumcol = ones(shape=self.nrows, typecode=numcol.typecode())
