@@ -6,7 +6,7 @@ Test module for enumerated types under PyTables
 :Contact:  ivilata@carabos.com
 :Created:  2005-05-09
 :License:  BSD
-:Revision: $Id: test_enum.py 2381 2007-02-16 18:06:40Z ivilata $
+:Revision: $Id: test_enum.py 3231 2007-09-12 11:03:14Z ivilata $
 """
 
 import unittest
@@ -203,7 +203,7 @@ class EnumTableTestCase(common.TempFileMixin, common.PyTablesTestCase):
     enumType = 'uint16'
 
 
-    def _description(self, shape=1):
+    def _description(self, shape=()):
         class TestDescription(tables.IsDescription):
             rid = tables.IntCol(pos=0)
             rcolor = tables.EnumCol(
@@ -383,7 +383,7 @@ class EnumEArrayTestCase(common.TempFileMixin, common.PyTablesTestCase):
     enumType = 'uint16'
 
 
-    def _atom(self, shape=1):
+    def _atom(self, shape=()):
         return tables.EnumAtom(
             self.enum, 'red', base=self.enumType, shape=shape)
 
@@ -483,7 +483,7 @@ class EnumVLArrayTestCase(common.TempFileMixin, common.PyTablesTestCase):
     enumType = 'uint16'
 
 
-    def _atom(self, shape=1):
+    def _atom(self, shape=()):
         return tables.EnumAtom(
             self.enum, 'red', base=self.enumType, shape=shape)
 
