@@ -5,24 +5,31 @@
 #       Author:  Ivan Vilata i Balaguer - reverse:com.carabos@ivilata
 #
 #       $Source: /home/ivan/_/programari/pytables/svn/cvs/pytables/pytables/test/test_timetype.py,v $
-#       $Id: test_timetype.py 1496 2006-03-13 09:48:13Z faltet $
+#       $Id: test_timetype.py 3035 2007-06-18 12:03:52Z faltet $
 #
 ########################################################################
 
 "Unit test for the Time datatypes."
 
-import unittest, tempfile, os
-import tables, numarray
-from common import verbose, allequal, cleanup
+import unittest
+import tempfile
+import os
+
+import numpy
+
+import tables
+from tables.tests import common
+from tables.tests.common import allequal
+
 # To delete the internal attributes automagically
-unittest.TestCase.tearDown = cleanup
+unittest.TestCase.tearDown = common.cleanup
 
 
-__revision__ = '$Id: test_timetype.py 1496 2006-03-13 09:48:13Z faltet $'
+__revision__ = '$Id: test_timetype.py 3035 2007-06-18 12:03:52Z faltet $'
 
 
 
-class LeafCreationTestCase(unittest.TestCase):
+class LeafCreationTestCase(common.PyTablesTestCase):
     "Tests creating Tables, VLArrays an EArrays with Time data."
 
     def setUp(self):
@@ -64,8 +71,10 @@ class LeafCreationTestCase(unittest.TestCase):
         self.h5file.createVLArray('/', 'vlarray8', tables.Time64Atom())
 
         # EArray creation.
-        self.h5file.createEArray('/', 'earray4', tables.Time32Atom(shape=(0,)))
-        self.h5file.createEArray('/', 'earray8', tables.Time64Atom(shape=(0,)))
+        self.h5file.createEArray('/', 'earray4',
+                                 tables.Time32Atom(), shape=(0,))
+        self.h5file.createEArray('/', 'earray8',
+                                 tables.Time64Atom(), shape=(0,))
 
 
     def test01_MultidimLeaves(self):
@@ -86,13 +95,13 @@ class LeafCreationTestCase(unittest.TestCase):
 
         # EArray creation.
         self.h5file.createEArray(
-                '/', 'earray4', tables.Time32Atom(shape=(0, 2, 1)))
+                '/', 'earray4', tables.Time32Atom(), shape=(0, 2, 1))
         self.h5file.createEArray(
-                '/', 'earray8', tables.Time64Atom(shape=(0, 2, 1)))
+                '/', 'earray8', tables.Time64Atom(), shape=(0, 2, 1))
 
 
 
-class OpenTestCase(unittest.TestCase):
+class OpenTestCase(common.PyTablesTestCase):
     "Tests opening a file with Time nodes."
 
     # The description used in the test Table.
@@ -145,22 +154,18 @@ class OpenTestCase(unittest.TestCase):
         # Test the Table node.
         tbl = h5file.root.table
         self.assertEqual(
-                tbl.coltypes['t32col'], self.MyTimeRow.columns['t32col'].type,
-                "Column types do not match.")
+                tbl.coldtypes['t32col'],
+                self.MyTimeRow.columns['t32col'].dtype,
+                "Column dtypes do not match.")
         self.assertEqual(
-                tbl.colshapes['t32col'], self.MyTimeRow.columns['t32col'].shape,
-                "Column shapes do not match.")
-        self.assertEqual(
-                tbl.coltypes['t64col'], self.MyTimeRow.columns['t64col'].type,
-                "Column types do not match.")
-        self.assertEqual(
-                tbl.colshapes['t64col'], self.MyTimeRow.columns['t64col'].shape,
-                "Column shapes do not match.")
+                tbl.coldtypes['t64col'],
+                self.MyTimeRow.columns['t64col'].dtype,
+                "Column dtypes do not match.")
 
         # Test the VLArray nodes.
         vla4 = h5file.root.vlarray4
         self.assertEqual(
-                vla4.atom.type, self.myTime32Atom.type,
+                vla4.atom.dtype, self.myTime32Atom.dtype,
                 "Atom types do not match.")
         self.assertEqual(
                 vla4.atom.shape, self.myTime32Atom.shape,
@@ -168,7 +173,7 @@ class OpenTestCase(unittest.TestCase):
 
         vla8 = h5file.root.vlarray8
         self.assertEqual(
-                vla8.atom.type, self.myTime64Atom.type,
+                vla8.atom.dtype, self.myTime64Atom.dtype,
                 "Atom types do not match.")
         self.assertEqual(
                 vla8.atom.shape, self.myTime64Atom.shape,
@@ -185,28 +190,30 @@ class OpenTestCase(unittest.TestCase):
         # Test the Table node.
         tbl = h5file.root.table
         self.assertEqual(
-                tbl.colstypes['t32col'], self.MyTimeRow.columns['t32col'].stype,
+                tbl.coltypes['t32col'],
+                self.MyTimeRow.columns['t32col'].type,
                 "Column types do not match.")
         self.assertEqual(
-                tbl.colstypes['t64col'], self.MyTimeRow.columns['t64col'].stype,
+                tbl.coltypes['t64col'],
+                self.MyTimeRow.columns['t64col'].type,
                 "Column types do not match.")
 
         # Test the VLArray nodes.
         vla4 = h5file.root.vlarray4
         self.assertEqual(
-                vla4.atom.stype, self.myTime32Atom.stype,
+                vla4.atom.type, self.myTime32Atom.type,
                 "Atom types do not match.")
 
         vla8 = h5file.root.vlarray8
         self.assertEqual(
-                vla8.atom.stype, self.myTime64Atom.stype,
+                vla8.atom.type, self.myTime64Atom.type,
                 "Atom types do not match.")
 
         h5file.close()
 
 
 
-class CompareTestCase(unittest.TestCase):
+class CompareTestCase(common.PyTablesTestCase):
     "Tests whether stored and retrieved time data is kept the same."
 
     # The description used in the test Table.
@@ -241,7 +248,7 @@ class CompareTestCase(unittest.TestCase):
     def test00_Compare32VLArray(self):
         "Comparing written 32-bit time data with read data in a VLArray."
 
-        wtime = numarray.array((1234567890,) * 2, numarray.Int32)
+        wtime = numpy.array((1234567890,) * 2, numpy.int32)
 
         # Create test VLArray with data.
         h5file = tables.openFile(
@@ -262,7 +269,7 @@ class CompareTestCase(unittest.TestCase):
     def test01_Compare64VLArray(self):
         "Comparing written 64-bit time data with read data in a VLArray."
 
-        wtime = numarray.array((1234567890.123456,) * 2, numarray.Float64)
+        wtime = numpy.array((1234567890.123456,) * 2, numpy.float64)
 
         # Create test VLArray with data.
         h5file = tables.openFile(
@@ -289,13 +296,14 @@ class CompareTestCase(unittest.TestCase):
         vla = h5file.createVLArray('/', 'test', self.myTime64Atom)
 
         # Size of the test.
-        nrows = vla._v_maxTuples + 34  # Add some more rows than buffer.
+        nrows = vla.nrowsinbuf + 34  # Add some more rows than buffer.
         # Only for home checks; the value above should check better
         # the I/O with multiple buffers.
-        ##nrows = 10
+        #nrows = 10
 
         for i in xrange(nrows):
-            vla.append((i + 0.012, i + 0.012))
+            j = i*2
+            vla.append((j + 0.012, j + 1 + 0.012))
         h5file.close()
 
         # Check the written data.
@@ -303,12 +311,12 @@ class CompareTestCase(unittest.TestCase):
         arr = h5file.root.test.read()
         h5file.close()
 
-        arr = numarray.array(arr)
-        orig_val = numarray.arange(0, nrows, 0.5, type = numarray.Int32,
-                                   shape = (nrows, 1, 2)) + 0.012
-        if verbose:
+        arr = numpy.array(arr)
+        orig_val = numpy.arange(0, nrows*2, dtype=numpy.int32) + 0.012
+        orig_val.shape = (nrows, 1, 2)
+        if common.verbose:
             print "Original values:", orig_val
-            print "Saved values:", arr
+            print "Retrieved values:", arr
         self.assert_(
                 allequal(arr, orig_val),
                 "Stored and retrieved values do not match.")
@@ -334,14 +342,12 @@ class CompareTestCase(unittest.TestCase):
         recarr = h5file.root.test.read(0)
         h5file.close()
 
-        self.assertEqual(
-                recarr.field('t32col')[0], int(wtime),
-                "Stored and retrieved values do not match.")
+        self.assertEqual(recarr['t32col'][0], int(wtime),
+                         "Stored and retrieved values do not match.")
 
-        comp = (recarr.field('t64col')[0] == numarray.array((wtime, wtime)))
-        self.assert_(
-                numarray.alltrue(comp),
-                "Stored and retrieved values do not match.")
+        comp = (recarr['t64col'][0] == numpy.array((wtime, wtime)))
+        self.assert_(numpy.alltrue(comp),
+                     "Stored and retrieved values do not match.")
 
 
     def test02b_CompareTable(self):
@@ -353,7 +359,7 @@ class CompareTestCase(unittest.TestCase):
         tbl = h5file.createTable('/', 'test', self.MyTimeRow)
 
         # Size of the test.
-        nrows = tbl._v_maxTuples + 34  # Add some more rows than buffer.
+        nrows = tbl.nrowsinbuf + 34  # Add some more rows than buffer.
         # Only for home checks; the value above should check better
         # the I/O with multiple buffers.
         ##nrows = 10
@@ -361,7 +367,8 @@ class CompareTestCase(unittest.TestCase):
         row = tbl.row
         for i in xrange(nrows):
             row['t32col'] = i
-            row['t64col'] = (i+0.012, i+0.012)
+            j = i*2
+            row['t64col'] = (j+0.012, j+1+0.012)
             row.append()
         h5file.close()
 
@@ -371,41 +378,41 @@ class CompareTestCase(unittest.TestCase):
         h5file.close()
 
         # Time32 column.
-        orig_val = numarray.arange(nrows, type = numarray.Int32)
-        if verbose:
+        orig_val = numpy.arange(nrows, dtype=numpy.int32)
+        if common.verbose:
             print "Original values:", orig_val
-            print "Saved values:", recarr.field('t32col')[:]
+            print "Retrieved values:", recarr['t32col'][:]
         self.assert_(
-                numarray.alltrue(recarr.field('t32col')[:] == orig_val),
+                numpy.alltrue(recarr['t32col'][:] == orig_val),
                 "Stored and retrieved values do not match.")
 
         # Time64 column.
-        orig_val = numarray.arange(0, nrows, 0.5, type = numarray.Int32,
-                                   shape = (nrows, 2)) + 0.012
-        if verbose:
+        orig_val = numpy.arange(0, nrows*2, dtype=numpy.int32) + 0.012
+        orig_val.shape = (nrows, 2)
+        if common.verbose:
             print "Original values:", orig_val
-            print "Saved values:", recarr.field('t64col')[:]
+            print "Retrieved values:", recarr['t64col'][:]
         self.assert_(
-    allequal(recarr.field('t64col')[:], orig_val, numarray.Float64),
-                "Stored and retrieved values do not match.")
+            allequal(recarr['t64col'][:], orig_val, numpy.float64),
+            "Stored and retrieved values do not match.")
 
 
     def test03_Compare64EArray(self):
         "Comparing written 64-bit time data with read data in an EArray."
 
-        wtime = numarray.array((1234567890.123456,) * 2)
+        wtime = 1234567890.123456
 
         # Create test EArray with data.
         h5file = tables.openFile(
-                self.h5fname, 'w', title = "Test for comparing Time64 E arrays")
+                self.h5fname, 'w', title = "Test for comparing Time64 EArrays")
         ea = h5file.createEArray(
-                '/', 'test', tables.Time64Atom(shape = (0, 2)))
+                '/', 'test', tables.Time64Atom(), shape=(0,))
         ea.append((wtime,))
         h5file.close()
 
         # Check the written data.
         h5file = tables.openFile(self.h5fname)
-        rtime = h5file.root.test.read()[0]
+        rtime = h5file.root.test[0]
         h5file.close()
         self.assert_(
                 allequal(rtime, wtime),
@@ -419,16 +426,17 @@ class CompareTestCase(unittest.TestCase):
         h5file = tables.openFile(
                 self.h5fname, 'w', title = "Test for comparing Time64 E arrays")
         ea = h5file.createEArray(
-                '/', 'test', tables.Time64Atom(shape = (0, 2)))
+                '/', 'test', tables.Time64Atom(), shape=(0, 2))
 
         # Size of the test.
-        nrows = ea._v_maxTuples + 34  # Add some more rows than buffer.
+        nrows = ea.nrowsinbuf + 34  # Add some more rows than buffer.
         # Only for home checks; the value above should check better
         # the I/O with multiple buffers.
         ##nrows = 10
 
         for i in xrange(nrows):
-            ea.append(((i + 0.012, i + 0.012),))
+            j = i * 2
+            ea.append(((j + 0.012, j + 1 + 0.012),))
         h5file.close()
 
         # Check the written data.
@@ -436,18 +444,18 @@ class CompareTestCase(unittest.TestCase):
         arr = h5file.root.test.read()
         h5file.close()
 
-        orig_val = numarray.arange(0, nrows, 0.5, type = numarray.Int32,
-                                   shape = (nrows, 2)) + 0.012
-        if verbose:
+        orig_val = numpy.arange(0, nrows*2, dtype=numpy.int32) + 0.012
+        orig_val.shape = (nrows, 2)
+        if common.verbose:
             print "Original values:", orig_val
-            print "Saved values:", arr
+            print "Retrieved values:", arr
         self.assert_(
                 allequal(arr, orig_val),
                 "Stored and retrieved values do not match.")
 
 
 
-class UnalignedTestCase(unittest.TestCase):
+class UnalignedTestCase(common.PyTablesTestCase):
     "Tests writing and reading unaligned time values in a table."
 
     # The description used in the test Table.
@@ -486,7 +494,7 @@ class UnalignedTestCase(unittest.TestCase):
         tbl = h5file.createTable('/', 'test', self.MyTimeRow)
 
         # Size of the test.
-        nrows = tbl._v_maxTuples + 34  # Add some more rows than buffer.
+        nrows = tbl.nrowsinbuf + 34  # Add some more rows than buffer.
         # Only for home checks; the value above should check better
         # the I/O with multiple buffers.
         ##nrows = 10
@@ -495,7 +503,8 @@ class UnalignedTestCase(unittest.TestCase):
         for i in xrange(nrows):
             row['i8col']  = i
             row['t32col'] = i
-            row['t64col'] = (i+0.012, i+0.012)
+            j = i * 2
+            row['t64col'] = (j+0.012, j+1+0.012)
             row.append()
         h5file.close()
 
@@ -505,35 +514,143 @@ class UnalignedTestCase(unittest.TestCase):
         h5file.close()
 
         # Int8 column.
-        orig_val = numarray.arange(nrows, type = numarray.Int8)
-        if verbose:
+        orig_val = numpy.arange(nrows, dtype=numpy.int8)
+        if common.verbose:
             print "Original values:", orig_val
-            print "Saved values:", recarr.field('i8col')[:]
+            print "Retrieved values:", recarr['i8col'][:]
         self.assert_(
-                numarray.alltrue(recarr.field('i8col')[:] == orig_val),
+                numpy.alltrue(recarr['i8col'][:] == orig_val),
                 "Stored and retrieved values do not match.")
 
         # Time32 column.
-        orig_val = numarray.arange(nrows, type = numarray.Int32)
-        if verbose:
+        orig_val = numpy.arange(nrows, dtype=numpy.int32)
+        if common.verbose:
             print "Original values:", orig_val
-            print "Saved values:", recarr.field('t32col')[:]
+            print "Retrieved values:", recarr['t32col'][:]
         self.assert_(
-                numarray.alltrue(recarr.field('t32col')[:] == orig_val),
+                numpy.alltrue(recarr['t32col'][:] == orig_val),
                 "Stored and retrieved values do not match.")
 
         # Time64 column.
-        orig_val = numarray.arange(0, nrows, 0.5, type = numarray.Int32,
-                                   shape = (nrows, 2)) + 0.012
-        if verbose:
+        orig_val = numpy.arange(0, nrows*2, dtype=numpy.int32) + 0.012
+        orig_val.shape = (nrows, 2)
+        if common.verbose:
             print "Original values:", orig_val
-            print "Saved values:", recarr.field('t64col')[:]
+            print "Retrieved values:", recarr['t64col'][:]
         self.assert_(
-    allequal(recarr.field('t64col')[:], orig_val, numarray.Float64),
-                "Stored and retrieved values do not match.")
+            allequal(recarr['t64col'][:], orig_val, numpy.float64),
+            "Stored and retrieved values do not match.")
 
 
 
+class BigEndianTestCase(common.PyTablesTestCase):
+    "Tests for reading big-endian time values in arrays and nested tables."
+
+    def setUp(self):
+        filename = self._testFilename('times-nested-be.h5')
+        self.h5f = tables.openFile(filename, 'r')
+
+
+    def tearDown(self):
+        self.h5f.close()
+
+
+    def test00a_Read32Array(self):
+        "Checking Time32 type in arrays."
+
+        # Check the written data.
+        earr = self.h5f.root.earr32[:]
+
+        # Generate the expected Time32 array.
+        start = 1178896298
+        nrows = 10
+        orig_val = numpy.arange(start, start+nrows, dtype=numpy.int32)
+
+        if common.verbose:
+            print "Retrieved values:", earr
+            print "Should look like:", orig_val
+        self.assert_(
+                numpy.alltrue(earr == orig_val),
+                "Retrieved values do not match the expected values.")
+
+
+    def test00b_Read64Array(self):
+        "Checking Time64 type in arrays."
+
+        # Check the written data.
+        earr = self.h5f.root.earr64[:]
+
+        # Generate the expected Time64 array.
+        start = 1178896298.832258
+        nrows = 10
+        orig_val = numpy.arange(start, start+nrows, dtype=numpy.float64)
+
+        if common.verbose:
+            print "Retrieved values:", earr
+            print "Should look like:", orig_val
+        self.assert_(
+                numpy.allclose(earr, orig_val, rtol=1.e-15),
+                "Retrieved values do not match the expected values.")
+
+
+    def test01a_ReadPlainColumn(self):
+        "Checking Time32 type in plain columns."
+
+        # Check the written data.
+        t32 = self.h5f.root.tbl.cols.t32[:]
+
+        # Generate the expected Time32 array.
+        start = 1178896298
+        nrows = 10
+        orig_val = numpy.arange(start, start+nrows, dtype=numpy.int32)
+
+        if common.verbose:
+            print "Retrieved values:", t32
+            print "Should look like:", orig_val
+        self.assert_(
+                numpy.alltrue(t32 == orig_val),
+                "Retrieved values do not match the expected values.")
+
+
+    def test01b_ReadNestedColumn(self):
+        "Checking Time64 type in nested columns."
+
+        # Check the written data.
+        t64 = self.h5f.root.tbl.cols.nested.t64[:]
+
+        # Generate the expected Time64 array.
+        start = 1178896298.832258
+        nrows = 10
+        orig_val = numpy.arange(start, start+nrows, dtype=numpy.float64)
+
+        if common.verbose:
+            print "Retrieved values:", t64
+            print "Should look like:", orig_val
+        self.assert_(
+                numpy.allclose(t64, orig_val, rtol=1.e-15),
+                "Retrieved values do not match the expected values.")
+
+
+    def test02_ReadNestedColumnTwice(self):
+        "Checking Time64 type in nested columns (read twice)."
+
+        # Check the written data.
+        _ = self.h5f.root.tbl.cols.nested.t64[:]
+        t64 = self.h5f.root.tbl.cols.nested.t64[:]
+
+        # Generate the expected Time64 array.
+        start = 1178896298.832258
+        nrows = 10
+        orig_val = numpy.arange(start, start+nrows, dtype=numpy.float64)
+
+        if common.verbose:
+            print "Retrieved values:", t64
+            print "Should look like:", orig_val
+        self.assert_(
+                numpy.allclose(t64, orig_val, rtol=1.e-15),
+                "Retrieved values do not match the expected values.")
+
+
 #----------------------------------------------------------------------
 
 def suite():
@@ -548,9 +665,7 @@ def suite():
     theSuite.addTest(unittest.makeSuite(OpenTestCase))
     theSuite.addTest(unittest.makeSuite(CompareTestCase))
     theSuite.addTest(unittest.makeSuite(UnalignedTestCase))
-
-# More tests are needed so as to check atributes, compression, exceptions,
-# etc... Francesc Altet 2005-01-06
+    theSuite.addTest(unittest.makeSuite(BigEndianTestCase))
 
     return theSuite
 
